@@ -242,9 +242,10 @@ class SSHClient(object):
                     return ExecResult(self.__ip, self.__port, 1, "", "SSH连接已关闭或不可用，重连失败")
 
             thread_result = _ThreadResult()
-
+            caller_thread_name = threading.current_thread().name
             def _thread_func():
                 try:
+                    threading.current_thread().name = caller_thread_name
                     thread_result.result = self._exec(cmd, promt_response, timeout)
                 except Exception as inner_e:
                     thread_result.error = inner_e
